import React, { useState } from 'react';
import StatusCard, { DataRow } from '@/components/StatusCard';
import styles from './index.less';
import { useDashboard } from '@/pages/Home_v_2504/components/context';

// 导入图标 - 暂时都使用bike图标
import bikeIcon from '@/assets/images/V-2504/main-bike.png';
import restaurantIcon from '@/assets/images/V-2504/main-restaurant.png';
import drainageIcon from '@/assets/images/V-2504/main-drainage.png';
import toiletIcon from '@/assets/images/V-2504/main-toilet.png';
import lightingIcon from '@/assets/images/V-2504/main-lighting.png';
import manholeIcon from '@/assets/images/V-2504/main-manhole.png';
import patrolIcon from '@/assets/images/V-2504/main-patrol.png';
import onlineIcon from '@/assets/images/V-2504/main-online.png';
import complaintIcon from '@/assets/images/V-2504/main-complaint.png';

interface CardConfig {
  id: string;
  title: string;
  iconSrc: string;
  iconStyle?: React.CSSProperties;
  dataRows: DataRow[];
  pageKey?: string;
}

const LeftBottom: React.FC = () => {
  const [activeCardId, setActiveCardId] = useState<string>(); // 'toilet'
  const { setActivePage, setIsTransitioning } = useDashboard();

  // 卡片数据配置 - 根据UI图精确配置
  const cardConfigs: CardConfig[] = [
    {
      id: 'bike',
      title: '共享单车',
      iconSrc: bikeIcon,
      iconStyle: { width: '68px', height: '63.5px' },
      // iconStyle: { width: '48px', height: '43px', objectFit: 'contain', position: 'absolute', top: '25px', left: '50%', transform: 'translateX(-50%)' },
      
      dataRows: [
        {
          label: '在线',
          value: 95.25,
          unit: '万辆',
          decimals: 2
        },
        {
          label: '今日告警',
          value: 562,
          unit: '次',
          status: 'error',
          decimals: 0
        },
      ],
    },
    {
      id: 'restaurant',
      title: '餐饮油烟',
      iconSrc: restaurantIcon,
      iconStyle: { width: '43.5px', height: '51.5px' },
      dataRows: [
        {
          label: '在线',
          value: 95.25,
          unit: '个',
          decimals: 2
        },
        {
          label: '今日告警',
          value: 562,
          unit: '次',
          status: 'error',
          decimals: 0
        },
      ],
      pageKey: 'restaurantOil',
    },
    {
      id: 'drainage',
      title: '智慧管廊',
      iconSrc: drainageIcon,
      iconStyle: { width: '60px', height: '55.5px' },
      dataRows: [
        {
          label: '在线',
          value: 95.25,
          unit: '个',
          decimals: 2
        },
        {
          label: '今日告警',
          value: 562,
          unit: '次',
          status: 'error',
          decimals: 0
        },
      ],
    },
    {
      id: 'toilet',
      title: '智慧公厕',
      iconSrc: toiletIcon,
      iconStyle: { width: '54px', height: '61px' },
      dataRows: [
        {
          label: '在线',
          value: 95.25,
          unit: '个',
          decimals: 2
        },
        {
          label: '今日告警',
          value: 562,
          unit: '次',
          status: 'error',
          decimals: 0
        },
      ],
    },
    {
      id: 'lighting',
      title: '智慧照明',
      iconSrc: lightingIcon,
      iconStyle: { width: '60px', height: '64px' },
      dataRows: [
        {
          label: '在线',
          value: 9525,
          unit: '个',
          decimals: 0
        },
        {
          label: '今日告警',
          value: 562,
          unit: '次',
          status: 'error',
          decimals: 0
        },
      ],
    },
    {
      id: 'manhole',
      title: '智慧井盖',
      iconSrc: manholeIcon,
      iconStyle: { width: '54.5px', height: '54.5px' },
      dataRows: [
        {
          label: '在线',
          value: 9525,
          unit: '个',
          decimals: 0
        },
        {
          label: '今日告警',
          value: 562,
          unit: '次',
          status: 'error',
          decimals: 0
        },
      ],
    },
    {
      id: 'patrol',
      title: '数字巡查',
      iconSrc: patrolIcon,
      iconStyle: { width: '59px', height: '59px' },
      dataRows: [
        {
          label: '智能上报',
          value: 9525,
          unit: '件',
          decimals: 0
        },
        {
          label: '人工上报',
          value: 562,
          unit: '件',
          decimals: 0
        },
      ],
    },
    {
      id: 'online',
      title: '网络舆情',
      iconSrc: onlineIcon,
      iconStyle: { width: '68.5px', height: '54px' },
      dataRows: [
        {
          label: '今日发现',
          value: 5623,
          unit: '件',
          decimals: 0
        },
      ],
    },
    {
      id: 'complaint',
      title: '百姓投诉',
      iconSrc: complaintIcon,
      iconStyle: { width: '57px', height: '60px' },
      dataRows: [
        {
          label: '今日投诉',
          value: 1563,
          unit: '次',
          decimals: 0
        },
      ],
    },
  ];

  const handleCardClick = (id: string, pageKey?: string) => {
    setActiveCardId(id);
    
    // 如果有对应的页面key，则跳转到对应的子页面
    if (pageKey) {
      setIsTransitioning(true);
      setTimeout(() => {
        setActivePage(pageKey);
        setIsTransitioning(false);
      }, 500); // 500ms的过渡动画时间
    }
  };

  return (
    <div className={styles.container}>
      <div className={styles.cardsContainer}>
        {cardConfigs.map((card) => (
          <StatusCard
            key={card.id}
            title={card.title}
            iconSrc={card.iconSrc}
            dataRows={card.dataRows}
            isActive={activeCardId === card.id}
            onClick={() => handleCardClick(card.id, card.pageKey)}
            iconStyle={card.iconStyle}
          />
        ))}
      </div>
    </div>
  );
};

export default LeftBottom; 