import React, { useState, useEffect } from 'react';
import { useRequest } from 'ahooks';
import styles from './index.less';
import SubTitle from '../../../common/SubTitle';
import NumberBoard from '@/components/NumberBoard';
import DataItem from '@/components/DataItem';

// 导入资源
import titleBg from '@/assets/images/V-2504/running-title-bg.png';
import titleBgActive from '@/assets/images/V-2504/running-title-bg-active.png';
import titleText from '@/assets/images/V-2504/running-title.png';
import staffLogo from '@/assets/images/V-2504/running-logo-1.png';
import deviceLogo from '@/assets/images/V-2504/running-logo-2.png';

let defaultData = 9799;

const testData = () => {
  const result = Math.floor(Math.random() * 50); // 测试用随机数字
  // const result = Math.floor(Math.random() * 999999); // 测试用随机数字
  defaultData = defaultData + result;
  return defaultData;
}
// 模拟API
const fetchRunningStatusData = async () => {
  // 模拟数据
  return {
    todayIssues: testData(), // 测试用随机数字
    staffData: {
      online: 95.25, // 城管人员在线
      unit: '万人在线'
    },
    deviceData: {
      online: 95.25, // 物联感知设备在线
      unit: '万个在线'
    }
  };
};

const LeftTopRunning: React.FC = () => {
  // 状态管理
  const [titleBarActive, setTitleBarActive] = useState(false);
  const [activeItem, setActiveItem] = useState<'staff' | 'device' | null>(null);
  
  // 获取运行态势数据
  const { data, loading } = useRequest(fetchRunningStatusData, {
    pollingInterval: 3000, // 每3秒刷新一次
  });
  
  // 处理标题栏点击
  const handleTitleBarClick = () => {
    // setTitleBarActive(!titleBarActive);
  };
  
  // 处理数据项点击
  const handleItemClick = (type: 'staff' | 'device') => {
    setActiveItem(activeItem === type ? null : type);
  };
  
  // 处理标题栏鼠标进入
  const handleTitleBarMouseEnter = () => {
    setTitleBarActive(true);
  };
  
  // 处理标题栏鼠标离开 
  const handleTitleBarMouseLeave = () => {
    setTitleBarActive(false);
  };
  
  if (loading || !data) {
    return <div className={styles.loading}>加载中...</div>;
  }

  return (
    <div className={styles.container}>
      <div className={styles.background}></div>      
      <SubTitle title="运行态势" />
      
      <div className={styles.content}>
        {/* 今日新增城市管理问题 */}
        <div 
          className={styles.titleBar} 
          onClick={handleTitleBarClick}
          onMouseEnter={handleTitleBarMouseEnter}
          onMouseLeave={handleTitleBarMouseLeave}
          style={{ 
            backgroundImage: `url(${titleBarActive ? titleBgActive : titleBg})` 
          }}
        >
          <img src={titleText} className={styles.titleText} alt="今日新增城市管理问题" />
        </div>
        
        {/* 数字展示板 */}
        <div className={styles.numberBoardContainer}>
          <NumberBoard number={data.todayIssues} totalDigits={6} />
        </div>
        
        {/* 城管人员和物联感知设备数据 */}
        <div className={styles.dataItemsContainer}>
          <DataItem 
            title="城管人员"
            value={data.staffData.online}
            unit={data.staffData.unit}
            logoSrc={staffLogo}
            active={activeItem === 'staff'}
            onClick={() => handleItemClick('staff')}
          />
          <DataItem 
            title="物联感知设备"
            value={data.deviceData.online}
            unit={data.deviceData.unit}
            logoSrc={deviceLogo}
            active={activeItem === 'device'}
            onClick={() => handleItemClick('device')}
          />
        </div>
      </div>
    </div>
  );
};

export default LeftTopRunning; 