import React, { useState } from 'react';
import classNames from 'classnames';
import styles from './index.less';

// 定义按钮组数据类型
interface ButtonGroupData {
  level1: Array<{
    key: string;
    label: string;
    hasChildren?: boolean;
  }>;
  level2: Record<string, Array<{
    key: string;
    label: string;
    hasChildren?: boolean;
  }>>;
  level3: Record<string, Array<{
    key: string;
    label: string;
  }>>;
}

const AreaSelector: React.FC = () => {
  // 按钮组数据
  const buttonGroupData: ButtonGroupData = {
    level1: [
      { key: 'chengdu', label: '成都市', hasChildren: true },
      { key: 'oilSmoke', label: '油烟事件' },
      { key: 'oilSmokeAlert', label: '油烟告警' },
      { key: 'restaurant', label: '餐饮企业' },
    ],
    level2: {
      chengdu: [
        { key: 'gaoxin', label: '高新区' },
        { key: 'jinjiang', label: '锦江区', hasChildren: true },
        { key: 'chenghua', label: '成华区' },
        { key: 'qingyang', label: '青羊区', hasChildren: true },
        { key: 'jinniu', label: '金牛区' },
        { key: 'xindou', label: '新都区' },
        { key: 'wuhou', label: '武侯区', hasChildren: true },
        { key: 'longquanyi', label: '龙泉驿区' },
        { key: 'wenjiang', label: '温江区' },
        { key: 'pengzhou', label: '彭州市' },
        { key: 'xinjin', label: '新津区' },
        { key: 'dayi', label: '大邑县' },
        { key: 'jianyang', label: '简阳市' },
      ]
    },
    level3: {
      jinjiang: [
        { key: 'qingshuitang', label: '清水塘街道' },
        { key: 'sanlitun', label: '三里口街道' },
        { key: 'dafeng', label: '大丰街道' },
        { key: 'xindu', label: '新都街道' },
        { key: 'jinxing', label: '锦兴街道' },
        { key: 'zhujiang', label: '珠江街道' },
      ],
      qingyang: [
        { key: 'sanhe', label: '三河街道' },
        { key: 'shibanqiao', label: '石板桥街道' },
        { key: 'zhupanzhen', label: '竹盘珍街道' },
        { key: 'xindu2', label: '新都街道' },
      ],
      wuhou: [
        { key: 'wuhou1', label: '桂湖街道' },
        { key: 'wuhou2', label: '大丰街道' },
        { key: 'wuhou3', label: '三河街道' },
        { key: 'wuhou4', label: '石板桥街道' },
        { key: 'wuhou5', label: '竹盘珍街道' },
        { key: 'wuhou6', label: '新都街道' },
      ]
    }
  };

  // 状态管理
  const [activeLevel1, setActiveLevel1] = useState<string | null>(null);
  const [activeLevel2, setActiveLevel2] = useState<string | null>(null);

  // 控制第二层、第三层按钮组的显示
  const showLevel2 = activeLevel1 && buttonGroupData.level2[activeLevel1];
  const showLevel3 = activeLevel2 && buttonGroupData.level3[activeLevel2];

  // 处理第一层按钮点击
  const handleLevel1Click = (key: string, hasChildren?: boolean) => {
    if (activeLevel1 === key) {
      // 如果点击当前已激活的按钮，则取消选中
      setActiveLevel1(null);
      setActiveLevel2(null);
    } else {
      // 否则激活该按钮
      setActiveLevel1(key);
      setActiveLevel2(null);
    }
  };

  // 处理第二层按钮点击
  const handleLevel2Click = (key: string, hasChildren?: boolean) => {
    if (activeLevel2 === key) {
      // 如果点击当前已激活的按钮，则取消选中
      setActiveLevel2(null);
    } else {
      // 否则激活该按钮
      setActiveLevel2(key);
    }
  };

  return (
    <div className={styles.areaSelector}>
      {/* 第一层按钮组 */}
      <div className={styles.level1ButtonGroup}>
        {buttonGroupData.level1.map((button) => (
          <div 
            key={button.key}
            className={classNames(styles.button, {
              [styles.buttonActive]: activeLevel1 === button.key
            })}
            onClick={() => handleLevel1Click(button.key, button.hasChildren)}
          >
            {button.label}
            {activeLevel1 === button.key && button.hasChildren && (
              <img 
                src={require('@/assets/images/V-2504/map-district-arrow.png')} 
                className={styles.arrow}
                alt=""
              />
            )}
          </div>
        ))}
      </div>

      {/* 第二层按钮组 */}
      {showLevel2 && (
        <div className={styles.level2ButtonGroup}>
          {buttonGroupData.level2[activeLevel1!].map((button) => (
            <div 
              key={button.key}
              className={classNames(styles.button, {
                [styles.buttonActive]: activeLevel2 === button.key
              })}
              onClick={() => handleLevel2Click(button.key, button.hasChildren)}
            >
              {button.label}
            </div>
          ))}
        </div>
      )}

      {/* 第三层按钮组 */}
      {showLevel3 && (
        <div className={styles.level3ButtonGroup}>
          {buttonGroupData.level3[activeLevel2!].map((button) => (
            <div 
              key={button.key}
              className={styles.button}
            >
              {button.label}
            </div>
          ))}
        </div>
      )}
    </div>
  );
};

export default AreaSelector; 