import Tabs from '@/components/Tabs';
import React, { useMemo, useState } from 'react';
import DistrictMap from './DistrictMap';
import EmphasisAreaMap from './EmphasisAreaMap';
import MapNotification from './MapNotification';
import NavigationBar from './NavigationBar';
import AreaSelector from './AreaSelector';
import { useDashboard } from '../context';
import styles from './index.less';

const Map: Record<string, React.FC> = {
  '1': DistrictMap,
  '2': EmphasisAreaMap,
};
// const MapContainer: React.FC = () => {
//   return (
//     <div className={styles.container}>
//       {/* 地图区域 - 后续实现 */}
//       <div className={styles.mapControls}>
//         <div className={styles.tabItem + ' ' + styles.active}>桥梁分布</div>
//         <div className={styles.tabItem}>道路分布</div>
//         <div className={styles.tabItem}>桥梁位置分布</div>
//       </div>
//       <div className={styles.mapPlaceholder}>
//         {/* 地图将在未来实现 */}
//         <span>地图区域 - 后续实现</span>
//       </div>
//     </div>
//   );
// };

const MapContainer = () => {
  const [topKey, setTopKey] = useState('1');
  const { activePage } = useDashboard();
  const isHomePage = activePage === 'home';

  const renderMap = useMemo(() => {
    const MapComponent = Map[topKey];
    return <MapComponent />;
  }, [topKey]);

  return (
    <div className={styles.container}>
      <div className={styles.topTabsWarp}>
        {/* <Tabs
          defaultValue="1"
          items={[
            { key: '1', label: '区（市）县' },
            { key: '2', label: '重点区域' },
          ]}
          onChange={(e) => {
            setTopKey(e);
          }}
        /> */}
      </div>
      
      {/* 地图上的最新事件和区域选择 */}
      <MapNotification districtName="金牛区" />
      
      {/* 只在下钻页面显示区域选择按钮组 */}
      {!isHomePage && <AreaSelector />}
      
      {/* 只在下钻页面显示导航栏 */}
      {!isHomePage && <NavigationBar />}
      
      <div className={styles.mapContent}>{renderMap}</div>
    </div>
  );
};

export default MapContainer;