import React from 'react';
import ModuleTitleWithTabs from '@/pages/Home_v_2504/components/common/ModuleTitleWithTabs';
import DescriptionItem from '@/components/DescriptionItem';
import StatCard from '@/components/V2504/StatCard';
import styles from './index.less';

// 导入图标
import dayLogo from '@/assets/images/V-2504/RestaurantOil-logo-day.png';
import smallLogo1 from '@/assets/images/V-2504/RestaurantOil-logo-small-1.png';
import smallLogo2 from '@/assets/images/V-2504/RestaurantOil-logo-small-2.png';

interface DailyOverallSectionProps {
  deviceCount: number; // 设备总数
  alertCount: number; // 告警次数
  onlineRate: number; // 在线率
  offlineRate: number; // 离线率
}

const DailyOverallSection: React.FC<DailyOverallSectionProps> = ({
  deviceCount = 253,
  alertCount = 1562,
  onlineRate = 90.3,
  offlineRate = 9.7
}) => {
  const valueStyle = {
    fontSize: '28px',
  }
  const offlineValueStyle = {
    background: 'linear-gradient(180.00deg, rgb(255, 204, 122), rgb(235, 151, 62))',
    WebkitBackgroundClip: 'text',
    WebkitTextFillColor: 'transparent',
    ...valueStyle
  }
  const unitStyle = {
    fontSize: '16px',
    fontWeight: 400,
    // marginRight: '4px',
  }
  const labelStyle = {
    fontSize: '16px',
    fontWeight: 400,
    marginRight: '14px',
  }
  const commonStyle = {
    justifyContent: 'flex-end',
  }
  
  return (
    <div className={styles.overallSection}>
      <ModuleTitleWithTabs title="整体情况" />
      <div className={styles.content}>
        {/* 第一行卡片 */}
        <div className={styles.topCard}>
          <div className={styles.logoWrapper}>
            <img src={dayLogo} className={styles.logo} alt="Logo" />
          </div>
          <div className={styles.deviceInfoWrapper}>
            <DescriptionItem
              value={deviceCount}
              name="总计"
              unit="万个"
              direction="horizontal"
              decimals={2}
              unitStyle={unitStyle}
              labelStyle={labelStyle}
              style={commonStyle}
            />
          </div>
          <div className={styles.alertCountWrapper}>
            <DescriptionItem
              value={alertCount}
              name="告警"
              unit="次"
              direction="horizontal"
              valueStyle={{ color: 'rgb(255, 79, 79)', ...valueStyle }}
              unitStyle={unitStyle}
              labelStyle={labelStyle}
              style={{ justifyContent: 'space-between' }}
            />
          </div>
        </div>

        {/* 第二行卡片 */}
        <div className={styles.bottomCards}>
          <StatCard
            showTwoValues={true}
            direction="horizontal"
            value={onlineRate}
            secondValue={90.3}
            label="在线"
            unit="万个"
            secondUnit="%"
            secondValueDecimals={1}
            icon={smallLogo1}
            iconSize={{ width: 48, height: 48 }}
            valueDecimals={2}
            valueStyle={valueStyle }
            labelStyle={{ marginRight: '4px' }}
            secondValueStyle={valueStyle}
          />
          <StatCard
            showTwoValues={true}
            direction="horizontal"
            value={offlineRate}
            secondValue={16.3}
            label="离线"
            unit="万个"
            secondUnit="%"
            secondValueDecimals={1}
            icon={smallLogo2}
            iconSize={{ width: 48, height: 48 }}
            valueStyle={offlineValueStyle}
            labelStyle={{ marginRight: '4px' }}
            secondValueStyle={offlineValueStyle}
            valueDecimals={2}
          />
        </div>
      </div>
    </div>
  );
};

export default DailyOverallSection; 