import React, { useState, useEffect } from 'react';
import ModuleTitleWithTabs from '@/pages/Home_v_2504/components/common/ModuleTitleWithTabs';
import BlueTable from '@/components/BlueTable';
import { ColumnsType } from 'antd/es/table';
import styles from './index.less';

interface MonitoringData {
  id: string;
  enterpriseName: string;
  onlineStatus: string;
  monitoringTime: string;
  status: string;
}

const RealtimeMonitoring: React.FC = () => {
  const [dataSource, setDataSource] = useState<MonitoringData[]>([]);

  // 模拟数据
  useEffect(() => {
    const mockData: MonitoringData[] = [];
    const statusOptions = ['正常', '告警'];
    const enterpriseNames = [
      '成都麻辣传奇火锅店',
      '宽窄巷子老灶火锅',
      '锦鲤古街风情火锅',
      '辣斗拉火锅春熙路店',
      '川西坝子火锅',
      '蜀九香火锅',
      '巴蜀大将火锅',
      '龙抄手火锅',
      '老妈蹄花火锅',
      '钢管厂老火锅',
      '洞子口张老二凉粉',
      '川西印象火锅',
      '成都麻辣传奇火锅店',
      '宽窄巷子老灶火锅',
      '锦鲤古街风情火锅',
      '辣斗拉火锅春熙路店',
      '川西坝子火锅',
    ];

    // 生成10条模拟数据
    for (let i = 0; i < enterpriseNames.length; i++) {
      const now = new Date();
      now.setMinutes(now.getMinutes() - i * 5);
      
      mockData.push({
        id: `${i + 1}`,
        enterpriseName: enterpriseNames[i],
        onlineStatus: '在线',
        monitoringTime: now.toLocaleTimeString('zh-CN', { hour: '2-digit', minute: '2-digit' }),
        // monitoringTime: now.toLocaleTimeString('zh-CN', { hour: '2-digit', minute: '2-digit', second: '2-digit' }),
        status: statusOptions[Math.floor(Math.random() * statusOptions.length)]
      });
    }

    setDataSource(mockData);
  }, []);

  // 定义表格列
  const columns: ColumnsType<MonitoringData> = [
    {
      title: '企业名称',
      dataIndex: 'enterpriseName',
      key: 'enterpriseName',
      ellipsis: true,
      width: 180,
    },
    {
      title: '在线情况',
      dataIndex: 'onlineStatus',
      key: 'onlineStatus',
      width: 100,
      render: (text) => (
        <div className={styles.statusTag}>{text}</div>
      )
    },
    {
      title: '监测时间',
      dataIndex: 'monitoringTime',
      key: 'monitoringTime',
      width: 120,
    },
    {
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      width: 90,
      render: (text) => (
        <div className={`${styles.statusTag} ${text === '告警' ? styles.warningTag : ''}`}>
          {text}
        </div>
      )
    }
  ];

  return (
    <div className={styles.container}>
      <ModuleTitleWithTabs title="实时监测" />
      <div className={styles.tableContainer}>
        <BlueTable
          columns={columns}
          dataSource={dataSource}
          pagination={false}
          size="middle"
          scroll={{ y: 840 }}
        />
      </div>
    </div>
  );
};

export default RealtimeMonitoring; 