import React, { useCallback, useState, useEffect } from 'react';
import PanelTitle from '@/pages/Home_v_2504/components/common/PanelTitle';
import DateSelector from '@/components/V2504/DateSelector';
import OverallSection from './components/OverallSection';
import DailyOverallSection from './components/DailyOverallSection';
import AlertTrend from './components/AlertTrend';
import AlertArea from './components/AlertArea';
import AlertRanking from './components/AlertRanking';
import RealtimeMonitoring from './components/RealtimeMonitoring';
import styles from './index.less';

// 类型定义
interface AreaData {
  name: string;
  percentage: number;
  count: number;
}

const LeftContent: React.FC = () => {
  // 状态
  const [dateType, setDateType] = useState<string>('day');
  const [dateRange, setDateRange] = useState<{ startTime: string; endTime: string }>({
    startTime: '',
    endTime: '',
  });
  
  // 各组件数据
  const [deviceCount, setDeviceCount] = useState<number>(5.98);
  const [alertCount, setAlertCount] = useState<number>(5.98);
  const [enterpriseCount, setEnterpriseCount] = useState<number>(1423);
  const [alertTrendData, setAlertTrendData] = useState<{ time: string; value: number }[]>([]);
  const [alertAreaData, setAlertAreaData] = useState<AreaData[]>([
    { name: '锦江区', percentage: 1520, count: 253 },
    { name: '金牛区', percentage: 1200, count: 200 },
    { name: '成华区', percentage: 1000, count: 167 },
    { name: '青羊区', percentage: 900, count: 150 },
    { name: '双流区', percentage: 800, count: 152 },
    { name: '武侯区', percentage: 700, count: 167 },
    { name: '龙泉驿区', percentage: 600, count: 167 },
    { name: '温江区', percentage: 500, count: 167 },
    { name: '新都区', percentage: 400, count: 167 },
    { name: '郫都区', percentage: 300, count: 167 },
    { name: '都江堰市', percentage: 200, count: 167 },
    { name: '彭州市', percentage: 100, count: 167 },
    { name: '邛崃市', percentage: 100, count: 167 },
    { name: '崇州市', percentage: 100, count: 167 },
    { name: '金堂县', percentage: 100, count: 167 },
    { name: '大邑县', percentage: 100, count: 167 },
    { name: '蒲江县', percentage: 100, count: 167 },
  ]);
  const [alertRankingData, setAlertRankingData] = useState<AreaData[]>([
    { name: '成都麻辣传奇火锅店', percentage: 87.2, count: 7582 },
    { name: '宽窄巷子老灶火锅', percentage: 83.5, count: 7277 },
    { name: '锦鲤古街风情火锅', percentage: 70.8, count: 7004 },
    { name: '辣斗拉火锅春熙路店', percentage: 65.6, count: 6985 },
    { name: '川西坝子火锅', percentage: 62.9, count: 6932 },
    { name: '蜀九香火锅', percentage: 60.6, count: 6820 },
    { name: '巴蜀大将火锅', percentage: 58.5, count: 6755 },
    { name: '龙抄手火锅', percentage: 55.4, count: 6666 },
    { name: '老妈蹄花火锅', percentage: 50.3, count: 6338 },
    { name: '钢管厂老火锅', percentage: 48.2, count: 6000 },
    { name: '洞子口张老二凉粉', percentage: 45.1, count: 5882 },
    { name: '川西印象火锅', percentage: 42.0, count: 5661 },
    { name: '成都麻辣传奇火锅店', percentage: 87.2, count: 7582 },
    { name: '宽窄巷子老灶火锅', percentage: 83.5, count: 7277 },
    { name: '锦鲤古街风情火锅', percentage: 70.8, count: 7004 },
    { name: '辣斗拉火锅春熙路店', percentage: 65.6, count: 6985 },
    { name: '川西坝子火锅', percentage: 62.9, count: 6932 },
    { name: '蜀九香火锅', percentage: 60.6, count: 6820 },
  ]);

  // 生成根据日期类型的趋势数据
  useEffect(() => {
    let mockData: { time: string; value: number }[] = [];
    
    if (dateType === 'day') {
      // 日期类型为天时，显示24小时数据
      mockData = Array.from({ length: 24 }, (_, i) => ({
        time: `${i.toString().padStart(2, '0')}:00`,
        value: Math.floor(Math.random() * 50) + 10
      }));
    } else if (dateType === 'year') {
      // 日期类型为年时，显示1月到12月的数据
      mockData = Array.from({ length: 12 }, (_, i) => ({
        time: `${i + 1}月`,
        value: Math.floor(Math.random() * 50) + 30
      }));
    } else if (dateType === 'range') {
      // 日期类型为范围时，使用日期范围内的数据
      const start = new Date(dateRange.startTime);
      const end = new Date(dateRange.endTime);
      const dayDiff = Math.ceil((end.getTime() - start.getTime()) / (1000 * 60 * 60 * 24));
      
      mockData = Array.from({ length: dayDiff + 1 }, (_, i) => {
        const currentDate = new Date(start);
        currentDate.setDate(start.getDate() + i);
        return {
          time: `${currentDate.getMonth() + 1}月${currentDate.getDate()}日`,
          value: Math.floor(Math.random() * 50) + 20
        };
      });
    } else {
      // 日期类型为月时，显示当月每一天的数据
      const now = new Date();
      const getMonthDays = () => {
        return new Date(now.getFullYear(), now.getMonth() + 1, 0).getDate();
      };
      
      mockData = Array.from({ length: getMonthDays() }, (_, i) => ({
        time: `${now.getMonth() + 1}月${i + 1}日`,
        value: Math.floor(Math.random() * 50) + 10
      }));
    }
    
    setAlertTrendData(mockData);
  }, [dateType, dateRange]);

  // 处理日期变化
  const handleDateChange = useCallback((params: { type: string; startTime: string; endTime: string }) => {
    console.log('Date changed:', params);
    setDateType(params.type);
    setDateRange({
      startTime: params.startTime,
      endTime: params.endTime,
    });
    
    // 这里可以根据日期变化重新获取数据
    // fetchDataByDateRange(params.startTime, params.endTime);
  }, []);

  // 根据日期类型渲染不同的整体情况组件
  const renderOverallSection = () => {
    if (dateType === 'day') {
      return (
        <DailyOverallSection 
          deviceCount={253}
          alertCount={1562}
          onlineRate={90.3}
          offlineRate={9.7}
        />
      );
    } else if (dateType === 'range' || dateType === 'year') {
      return (
        <OverallSection 
          deviceCount={enterpriseCount}
          alertCount={alertCount}
          isEnterprise={true}
        />
      );
    } else {
      // 月视图
      return (
        <OverallSection 
          deviceCount={deviceCount}
          alertCount={alertCount}
          isEnterprise={false}
        />
      );
    }
  };

  // 根据日期类型渲染右侧内容
  const renderRightContent = () => {
    if (dateType === 'day') {
      return (
        <RealtimeMonitoring />
      );
    } else {
      return (
        <AlertRanking
          data={alertRankingData}
        />
      );
    }
  };

  return (
    <div className={styles.container}>
      {/* 标题 */}
      <div className={styles.header}>
        <PanelTitle title="餐饮油烟实况" />
        <DateSelector
          onChange={handleDateChange}
          defaultType="day"
        />
      </div>

      <div className={styles.contentWrapper}>
        {/* 左侧内容区域 */}
        <div className={styles.leftSection}>
          {/* 整体情况 - 根据日期类型渲染不同组件 */}
          {renderOverallSection()}

          {/* 告警趋势 */}
          <AlertTrend
            data={alertTrendData}
            dateType={dateType}
          />

          {/* 告警区域 */}
          <AlertArea
            data={alertAreaData}
          />
        </div>

        {/* 右侧内容区域 - 根据日期类型渲染不同组件 */}
        <div className={styles.rightSection}>
          {renderRightContent()}
        </div>
      </div>
    </div>
  );
};

export default LeftContent; 