import React, { useState, useEffect } from 'react';
import ModuleTitleWithTabs from '@/pages/Home_v_2504/components/common/ModuleTitleWithTabs';
import AreaBarList, { AreaBarItem } from '@/components/V2504/AreaBarList';
import styles from './index.less';

// 类型定义
type AreaType = 'all' | 'urban' | 'central' | 'county';

interface CompletionRateProps {
  data?: AreaBarItem[];
  dateType?: string;
  dateRange?: { startTime: string; endTime: string };
}

const CompletionRate: React.FC<CompletionRateProps> = ({ 
  data = [
    { name: '锦江区', percentage: 87.2 },
    { name: '金牛区', percentage: 83.5 },
    { name: '成华区', percentage: 20.8 },
    { name: '青羊区', percentage: 15.6 },
    { name: '双流区', percentage: 12.9 },
  ],
  dateType = 'month',
  dateRange = { startTime: '', endTime: '' }
}) => {
  const [activeAreaType, setActiveAreaType] = useState<AreaType>('all');
  const [displayData, setDisplayData] = useState(data);

  // 根据日期类型和范围更新数据
  useEffect(() => {
    // 如果需要在日期变化时获取新的办结率数据
    // const newData = await fetchCompletionRateData(dateType, dateRange);
    // setDisplayData(newData);
    
    // 这里只是模拟数据变化
    if (dateType === 'day') {
      setDisplayData(data.map(item => ({
        ...item,
        percentage: Math.min(item.percentage * 1.1, 100)
      })));
    } else if (dateType === 'year') {
      setDisplayData(data.map(item => ({
        ...item,
        percentage: Math.min(item.percentage * 0.9, 100)
      })));
    } else {
      setDisplayData(data);
    }
  }, [dateType, dateRange, data]);

  return (
    <div className={styles.container}>
      <ModuleTitleWithTabs 
        title="办结率" 
        tabs={[
          { key: 'all', label: '全部' },
          { key: 'urban', label: '城市新区' },
          { key: 'central', label: '中心城区' },
          { key: 'county', label: '县市新城' },
        ]}
        activeKey={activeAreaType}
        onTabChange={(key) => setActiveAreaType(key as AreaType)}
      />
      <div className={styles.content}>
        <AreaBarList 
          data={displayData} 
          showCount={false} 
          height={290}
        />
      </div>
    </div>
  );
};

export default CompletionRate; 