import React, { useState, useEffect } from 'react';
import ModuleTitleWithTabs from '@/pages/Home_v_2504/components/common/ModuleTitleWithTabs';
import SmoothLineChart from '@/components/V2504/SmoothLineChart';
import styles from './index.less';

interface HighFrequencyProps {
  dateType?: string;
  dateRange?: { startTime: string; endTime: string };
}

const HighFrequency: React.FC<HighFrequencyProps> = ({ 
  dateType = 'month',
  dateRange = { startTime: '', endTime: '' }
}) => {
  const [data, setData] = useState<{ time: string; value: number }[]>([]);

  useEffect(() => {
    // 根据不同的日期类型生成不同的模拟数据
    let mockData: { time: string; value: number }[] = [];
    
    // 高发时段一般显示24小时的数据分布，不管什么日期类型
    mockData = Array.from({ length: 24 }, (_, i) => ({
      time: `${i.toString().padStart(2, '0')}:00`,
      value: Math.floor(Math.random() * 80) + 20
    }));
    
    setData(mockData);
  }, [dateType, dateRange]);

  return (
    <div className={styles.container}>
      <ModuleTitleWithTabs title="高发时段" />
      <div className={styles.chartContainer}>
        <SmoothLineChart 
          data={data} 
          unitText="单位：件"
          lineColorStop1="rgba(255, 188, 39, 0)"
          lineColorStop2="rgba(255, 188, 39, 0.36)"
          style={{ height: '150px', width: '100%' }}
        />
      </div>
    </div>
  );
};

export default HighFrequency; 