import React, { useState, useEffect } from 'react';
import ModuleTitleWithTabs from '@/pages/Home_v_2504/components/common/ModuleTitleWithTabs';
import AreaBarList, { AreaBarItem } from '@/components/V2504/AreaBarList';
import styles from './index.less';

// 类型定义
type AreaType = 'all' | 'urban' | 'central' | 'county';

interface HighFrequencyAreaProps {
  data?: AreaBarItem[];
  dateType?: string;
  dateRange?: { startTime: string; endTime: string };
}

const HighFrequencyArea: React.FC<HighFrequencyAreaProps> = ({ 
  data: initialData,
  dateType = 'month',
  dateRange = { startTime: '', endTime: '' }
}) => {
  const [activeAreaType, setActiveAreaType] = useState<AreaType>('all');
  const [data, setData] = useState<AreaBarItem[]>([]);

  // 初始默认数据
  const defaultData: AreaBarItem[] = [    
    { name: '锦江区', percentage: 97.2, count: 456 },
    { name: '金牛区', percentage: 83.5, count: 400 },
    { name: '成华区', percentage: 70.8, count: 322 },
    { name: '青羊区', percentage: 65.6, count: 186 },
    { name: '双流区', percentage: 12.9, count: 152 },
    { name: '武侯区', percentage: 10.6, count: 122 },
    { name: '龙泉驿区', percentage: 10.5, count: 121 },
    { name: '温江区', percentage: 10.4, count: 120 },
    { name: '新都区', percentage: 10.3, count: 119 },
    { name: '郫都区', percentage: 10.2, count: 118 },
    { name: '都江堰市', percentage: 10.1, count: 117 },
  ];


  // 根据日期类型和范围更新数据
  useEffect(() => {
    const currentData = initialData || defaultData;
    // console.log('currentData', currentData, dateType, dateRange);
    
    // 根据日期类型生成不同的模拟数据
    if (dateType === 'day') {
      setData(currentData.map(item => ({
        ...item,
        count: Math.floor((item.count || 0) * (0.8 + Math.random() * 0.4)),
        percentage: Math.floor((item.percentage || 0) * (0.8 + Math.random() * 0.4))
      })));
    } else if (dateType === 'year') {
      setData(currentData.map(item => ({
        ...item,
        count: Math.floor((item.count || 0) * (1.1 + Math.random() * 0.3)),
        percentage: Math.floor((item.percentage || 0) * (1.1 + Math.random() * 0.3))
      })));
    } else if (dateType === 'range') {
      setData(currentData.map(item => ({
        ...item,
        count: Math.floor((item.count || 0) * (0.9 + Math.random() * 0.5)),
        percentage: Math.floor((item.percentage || 0) * (0.9 + Math.random() * 0.5))
      })));
    } else {
      setData(currentData);
    }
  }, [initialData, dateType, dateRange]);

  return (
    <div className={styles.container}>
      <ModuleTitleWithTabs 
        title="高发区域" 
        tabs={[
          { key: 'all', label: '全部' },
          { key: 'urban', label: '城市新区' },
          { key: 'central', label: '中心城区' },
          { key: 'county', label: '县市新城' },
        ]}
        activeKey={activeAreaType}
        onTabChange={(key) => setActiveAreaType(key as AreaType)}
      />
      <div className={styles.content}>
        <AreaBarList 
          data={data} 
          // showCount={true}
          height={290}
          progressColor={{ from: 'rgb(53, 135, 255)', to: 'rgb(205, 148, 255)' }}
        />
      </div>
    </div>
  );
};

export default HighFrequencyArea; 