import React, { useState, useEffect } from 'react';
import ModuleTitleWithTabs from '@/pages/Home_v_2504/components/common/ModuleTitleWithTabs';
import SmoothLineChart from '@/components/V2504/SmoothLineChart';
import styles from './index.less';

// 类型定义

interface ProblemTrendProps {
  dateType?: string;
  dateRange?: { startTime: string; endTime: string };
}

const ProblemTrend: React.FC<ProblemTrendProps> = ({ 
  dateType = 'month',
  dateRange = { startTime: '', endTime: '' } 
}) => {
  const [data, setData] = useState<{ time: string; value: number }[]>([]);

  // 默认的月度数据
  // const defaultMonthData: DualData = {
  //   count: [
  //     { time: '1月', count: 185 },
  //     { time: '2月', count: 156 },
  //     { time: '3月', count: 203 },
  //     { time: '4月', count: 278 },
  //     { time: '5月', count: 235 },
  //     { time: '6月', count: 290 },
  //   ],
  //   rate: [
  //     { time: '1月', count: 12.5 },
  //     { time: '2月', count: 13.2 },
  //     { time: '3月', count: 15.8 },
  //     { time: '4月', count: 18.5 },
  //     { time: '5月', count: 16.9 },
  //     { time: '6月', count: 19.2 },
  //   ]
  // };
  
  // 生成根据日期类型的趋势数据
  useEffect(() => {
    let mockData: { time: string; value: number }[] = [];
    
    if (dateType === 'day') {
      // 日期类型为天时，显示24小时数据
      mockData = Array.from({ length: 24 }, (_, i) => ({
        time: `${i.toString().padStart(2, '0')}:00`,
        value: Math.floor(Math.random() * 50) + 10
      }));
    } else if (dateType === 'year') {
      // 日期类型为年时，显示1月到12月的数据
      mockData = Array.from({ length: 12 }, (_, i) => ({
        time: `${i + 1}月`,
        value: Math.floor(Math.random() * 50) + 30
      }));
    } else if (dateType === 'range') {
      // 日期类型为范围时，使用日期范围内的数据
      const start = new Date(dateRange.startTime);
      const end = new Date(dateRange.endTime);
      const dayDiff = Math.ceil((end.getTime() - start.getTime()) / (1000 * 60 * 60 * 24));
      
      mockData = Array.from({ length: dayDiff + 1 }, (_, i) => {
        const currentDate = new Date(start);
        currentDate.setDate(start.getDate() + i);
        return {
          time: `${currentDate.getMonth() + 1}月${currentDate.getDate()}日`,
          value: Math.floor(Math.random() * 50) + 20
        };
      });
    } else {
      // 日期类型为月时，显示当月每一天的数据
      const now = new Date();
      const getMonthDays = () => {
        return new Date(now.getFullYear(), now.getMonth() + 1, 0).getDate();
      };
      
      mockData = Array.from({ length: getMonthDays() }, (_, i) => ({
        time: `${now.getMonth() + 1}月${i + 1}日`,
        value: Math.floor(Math.random() * 50) + 10
      }));
    }
    
    setData(mockData);
  }, [dateType, dateRange]);
  // useEffect(() => {
  //   if (!initialData) {
  //     let newData: DualData = { count: [], rate: [] };

  //     // 根据dateType生成不同的数据
  //     if (dateType === 'day') {
  //       // 生成24小时的数据
  //       newData = {
  //         count: Array.from({ length: 24 }, (_, i) => ({
  //           time: `${i.toString().padStart(2, '0')}:00`,
  //           count: Math.floor(100 + Math.random() * 150)
  //         })),
  //         rate: Array.from({ length: 24 }, (_, i) => ({
  //           time: `${i.toString().padStart(2, '0')}:00`,
  //           count: 10 + Math.random() * 15
  //         }))
  //       };
  //     } else if (dateType === 'year') {
  //       // 生成1-12月的数据
  //       newData = {
  //         count: Array.from({ length: 12 }, (_, i) => ({
  //           time: `${i + 1}月`,
  //           count: Math.floor(150 + Math.random() * 200)
  //         })),
  //         rate: Array.from({ length: 12 }, (_, i) => ({
  //           time: `${i + 1}月`,
  //           count: 12 + Math.random() * 10
  //         }))
  //       };
  //     } else if (dateType === 'range' && dateRange.startTime && dateRange.endTime) {
  //       // 处理日期范围
  //       const startDate = new Date(dateRange.startTime);
  //       const endDate = new Date(dateRange.endTime);
  //       const diffTime = Math.abs(endDate.getTime() - startDate.getTime());
  //       const diffDays = Math.ceil(diffTime / (1000 * 60 * 60 * 24));
        
  //       // 根据范围长度决定显示粒度
  //       if (diffDays <= 7) {
  //         // 显示每天的数据
  //         newData = {
  //           count: Array.from({ length: diffDays }, (_, i) => {
  //             const date = new Date(startDate);
  //             date.setDate(date.getDate() + i);
  //             return {
  //               time: `${date.getMonth() + 1}/${date.getDate()}`,
  //               count: Math.floor(150 + Math.random() * 200)
  //             };
  //           }),
  //           rate: Array.from({ length: diffDays }, (_, i) => {
  //             const date = new Date(startDate);
  //             date.setDate(date.getDate() + i);
  //             return {
  //               time: `${date.getMonth() + 1}/${date.getDate()}`,
  //               count: 12 + Math.random() * 10
  //             };
  //           })
  //         };
  //       } else {
  //         // 显示每周的数据
  //         const weeks = Math.ceil(diffDays / 7);
  //         newData = {
  //           count: Array.from({ length: weeks }, (_, i) => ({
  //             time: `第${i + 1}周`,
  //             count: Math.floor(200 + Math.random() * 250)
  //           })),
  //           rate: Array.from({ length: weeks }, (_, i) => ({
  //             time: `第${i + 1}周`,
  //             count: 15 + Math.random() * 10
  //           }))
  //         };
  //       }
  //     } else {
  //       // 默认使用月度数据
  //       newData = defaultMonthData;
  //     }
      
  //     setChartData(newData);
  //   } else {
  //     setChartData(initialData);
  //   }
  // }, [initialData, dateType, dateRange]);

  

  return (
    <div className={styles.container}>
      <ModuleTitleWithTabs title="问题趋势" />
      <div className={styles.chartContainer}>
        <SmoothLineChart 
          data={data} 
          unitText="单位：件"
          lineColor="rgb(136, 238, 248)"
          lineColorStop1="rgba(136, 238, 248, 0)"
          lineColorStop2="rgba(136, 238, 248, 0.36)"
          style={{ height: '178px', width: '100%' }}
        />
      </div>
    </div>
  );
};

export default ProblemTrend; 