import React, { useEffect } from 'react';
import ModuleTitleWithTabs from '@/pages/Home_v_2504/components/common/ModuleTitleWithTabs';
import ChartWithLegend, { ChartDataItem } from '@/components/V2504/ChartWithLegend';
import styles from './index.less';

interface SourceSectionProps {
  data?: ChartDataItem[];
  dateType?: string;
  dateRange?: { startTime: string; endTime: string };
}

const SourceSection: React.FC<SourceSectionProps> = ({ 
  data = [
    { name: '市城运平台', value: 1625, percentage: 32.53 },
    { name: '12345市民投诉', value: 1589, percentage: 30.22 },
    { name: '数字城管巡查上报', value: 1233, percentage: 30.22 },
    { name: '其他', value: 1213, percentage: 30.12 },
  ],
  dateType = 'month',
  dateRange = { startTime: '', endTime: '' }
}) => {
  const colors = ['rgb(49, 198, 250)', 'rgb(255, 227, 53)', 'rgb(255, 155, 93)', 'rgb(71, 223, 155)', 'rgb(170, 145, 255)', 'rgb(97, 141, 255)'];
  // 这里可以根据dateType和dateRange在必要时更新数据
  useEffect(() => {
    // 如果需要在日期变化时获取新的来源数据
    // fetchSourceData(dateType, dateRange);
  }, [dateType, dateRange]);

  return (
    <div className={styles.container}>
      <ModuleTitleWithTabs title="问题来源" />
      <div className={styles.content}>
        <ChartWithLegend 
          data={data}
          colors={colors}
          chartWidth={170}
          chartHeight={170}
          unit="件"
          showPercentage={true}
          showCount={true}
        />
      </div>
    </div>
  );
};

export default SourceSection; 