import React from 'react';
import StatCard from '@/components/V2504/StatCard';
import styles from './index.less';

// Import stat card background images
import cardBg1 from '@/assets/images/V-2504/statcard-bg-1.png';
import cardBg2 from '@/assets/images/V-2504/statcard-bg-2.png';
import cardBg3 from '@/assets/images/V-2504/statcard-bg-3.png';
import cardBg4 from '@/assets/images/V-2504/statcard-bg-4.png';
import cardBg5 from '@/assets/images/V-2504/statcard-bg-5.png';

export interface StatisticsCardsProps {
  caseCount: number;
  processingCount: number;
  overtimeCount: number;
  completedCount: number;
  completionRate: number;
}

const StatisticsCards: React.FC<StatisticsCardsProps> = ({
  caseCount = 1000,
  processingCount = 862,
  overtimeCount = 126,
  completedCount = 2633,
  completionRate = 89.72,
}) => {
  return (
    <div className={styles.container}>
      <div className={styles.row}>
        <StatCard 
          value={caseCount}
          label="立案"
          unit="件"
          icon={cardBg1}
          iconSize={{ width: 45.84, height: 52.02 }}
          className={styles.smallCard}
        />
        
        <StatCard 
          value={processingCount}
          label="处置中"
          unit="件"
          icon={cardBg2}
          iconSize={{ width: 59, height: 59 }}
          valueStyle={{ background: 'linear-gradient(180.00deg, rgb(170, 255, 246),rgb(10, 192, 167))'}}
          className={styles.smallCard}
        />

        <StatCard 
          value={overtimeCount}
          label="超时"
          unit="件"
          icon={cardBg3}
          iconSize={{ width: 52, height: 52 }}
          valueStyle={{ background: 'rgb(255, 79, 79)'}}
          className={styles.smallCard}
        />
      </div>

      <div className={styles.row}>
        <StatCard 
          value={completedCount}
          label="已办结"
          unit="件"
          icon={cardBg4}
          iconSize={{ width: 48, height: 48 }}
          // valueStyle={{ color: '#31C6FA' }}
          // showTwoValues={true}
          // secondValue={completedCount}
          // secondUnit="件"
          // secondValueStyle={{ color: '#23EBE2' }}
          className={styles.largeCard}
          direction="horizontal"
        />
        
        <StatCard 
          value={completionRate}
          label="办结率"
          unit="%"
          icon={cardBg5}
          iconSize={{ width: 49, height: 49 }}
          // valueStyle={{ color: '#31C6FA' }}
          // showTwoValues={true}
          // secondValue={completionRate}
          // secondUnit="%"
          // secondValueStyle={{ color: '#23EBE2' }}
          className={styles.largeCard}
          direction="horizontal"
          valueDecimals={2}
        />
      </div>
    </div>
  );
};

export default StatisticsCards; 