import React, { useCallback, useState, useEffect } from 'react';
import PanelTitle from '@/pages/Home_v_2504/components/common/PanelTitle';
import DateSelector from '@/components/V2504/DateSelector';
import HighFrequency from './components/HighFrequency';
import ProblemTrend from './components/ProblemTrend';
import CompletionRate from './components/CompletionRate';
import HighFrequencyArea from './components/HighFrequencyArea';
import SourceSection from './components/SourceSection';
import StatisticsCards from './components/StatisticsCards';
import styles from './index.less';
import { Card, Typography } from 'antd';

const { Title } = Typography;

// 导入图标
import statusCardIcon from '@/assets/images/V-2504/main-complaint.png';

// 类型定义
type AreaType = 'all' | 'urban' | 'central' | 'county';

interface Statistic {
  caseCount: number;
  processingCount: number;
  overtimeCount: number;
  completedCount: number;
  completionRate: number;
}

interface AreaData {
  name: string;
  percentage: number;
  count: number;
}

const RightContent: React.FC = () => {
  // 状态
  const [dateType, setDateType] = useState<string>('month');
  const [dateRange, setDateRange] = useState<{ startTime: string; endTime: string }>({
    startTime: '',
    endTime: '',
  });
  const [statistics, setStatistics] = useState<Statistic>({
    caseCount: 1000,
    processingCount: 862,
    overtimeCount: 126,
    completedCount: 2633,
    completionRate: 89.72,
  });
  const [sourceData, setSourceData] = useState<{ name: string; value: number; percentage: number }[]>([
    { name: '市城运平台', value: 1625, percentage: 32.53 },
    { name: '12345市民投诉', value: 1589, percentage: 30.22 },
    { name: '数字城管巡查上报', value: 1233, percentage: 30.22 },
    { name: '其他', value: 1233, percentage: 30.22 },
  ]);
  const [completionRateData, setCompletionRateData] = useState<AreaData[]>([
    { name: '锦江区', percentage: 87.2, count: 0 },
    { name: '金牛区', percentage: 73.5, count: 0 },
    { name: '成华区', percentage: 60.8, count: 0 },
    { name: '青羊区', percentage: 55.6, count: 0 },
    { name: '双流区', percentage: 42.9, count: 0 },
    { name: '武侯区', percentage: 35.6, count: 0 },
    { name: '龙泉驿区', percentage: 30.5, count: 0 },
    { name: '温江区', percentage: 25.4, count: 0 },
    { name: '新都区', percentage: 20.3, count: 0 },
    { name: '郫都区', percentage: 15.2, count: 0 },
    { name: '都江堰市', percentage: 10.1, count: 0 },
  ]);
  // const [highFrequencyData, setHighFrequencyData] = useState<AreaData[]>([
  //   { name: '锦江区', percentage: 97.2, count: 456 },
  //   { name: '金牛区', percentage: 83.5, count: 400 },
  //   { name: '成华区', percentage: 70.8, count: 322 },
  //   { name: '青羊区', percentage: 65.6, count: 186 },
  //   { name: '双流区', percentage: 12.9, count: 152 },
  //   { name: '武侯区', percentage: 10.6, count: 122 },
  //   { name: '龙泉驿区', percentage: 10.5, count: 121 },
  //   { name: '温江区', percentage: 10.4, count: 120 },
  //   { name: '新都区', percentage: 10.3, count: 119 },
  //   { name: '郫都区', percentage: 10.2, count: 118 },
  //   { name: '都江堰市', percentage: 10.1, count: 117 },
  // ]);

  // 根据日期类型和范围获取数据
  useEffect(() => {
    // 这里可以根据dateType和dateRange从接口获取对应的数据
    console.log('获取数据:', dateType, dateRange);
    // 模拟不同日期类型下的数据变化
    
    // 更新统计数据
    if (dateType === 'day') {
      setStatistics({
        caseCount: 562,
        processingCount: 314,
        overtimeCount: 46,
        completedCount: 862,
        completionRate: 94.2,
      });
    } else if (dateType === 'year') {
      setStatistics({
        caseCount: 12500,
        processingCount: 1024,
        overtimeCount: 236,
        completedCount: 11240,
        completionRate: 91.6,
      });
    } else if (dateType === 'range') {
      setStatistics({
        caseCount: 5620,
        processingCount: 862,
        overtimeCount: 156,
        completedCount: 4602,
        completionRate: 87.5,
      });
    } else {
      // 月视图的默认数据
      setStatistics({
        caseCount: 1000,
        processingCount: 862,
        overtimeCount: 126,
        completedCount: 2633,
        completionRate: 89.72,
      });
    }
    
    // 此处可以调用API获取其他数据
    // fetchSourceData(dateType, dateRange);
    // fetchCompletionRateData(dateType, dateRange);
    // fetchHighFrequencyData(dateType, dateRange);
    
  }, [dateType, dateRange]);

  // 处理日期变化
  const handleDateChange = useCallback((params: { type: string; startTime: string; endTime: string }) => {
    console.log('Date changed:', params);
    setDateType(params.type);
    setDateRange({
      startTime: params.startTime,
      endTime: params.endTime,
    });
  }, []);

  return (
    <div className={styles.container}>
      {/* 标题 */}
      <div className={styles.header}>
        <PanelTitle title="餐饮油烟事件" />
        <DateSelector
          onChange={handleDateChange}
          defaultType="month"
        />
      </div>

      {/* 高发时段和统计卡片区域 */}
      <div className={styles.topSection}>
        <HighFrequency 
          dateType={dateType}
          dateRange={dateRange}
        />
        
        <StatisticsCards 
          caseCount={statistics.caseCount}
          processingCount={statistics.processingCount}
          overtimeCount={statistics.overtimeCount}
          completedCount={statistics.completedCount}
          completionRate={statistics.completionRate}
        />
      </div>

      {/* 中间内容 */}
      <div className={styles.middleContent}>
        {/* 问题来源 */}
        <SourceSection 
          data={sourceData}
          dateType={dateType}
          dateRange={dateRange}
        />
        
        {/* 问题趋势 */}
        <div className={styles.trendSection}>
          <ProblemTrend
            dateType={dateType}
            dateRange={dateRange}
          />
        </div>
      </div>

      {/* 底部内容 */}
      <div className={styles.bottomContent}>
        {/* 办结率 */}
        <CompletionRate 
          data={completionRateData}
          dateType={dateType}
          dateRange={dateRange}
        />
        {/* 高发区域 */}
        <HighFrequencyArea 
          // data={highFrequencyData}
          dateType={dateType}
          dateRange={dateRange}
        />
      </div>
    </div>
  );
};

export default RightContent; 