import React, { useEffect } from 'react';
import { useDashboard } from '../../context';
import RightContent from './components/RightContent';
import LeftContent from './components/LeftContent';
import styles from './index.less';

interface RestaurantOilProps {
  visible: boolean;
}

const RestaurantOil: React.FC<RestaurantOilProps> = ({ visible }) => {
  const { isTransitioning, transitionDirection } = useDashboard();

  // 如果需要在组件显示时加载数据，可以在这里处理
  useEffect(() => {
    if (visible && !isTransitioning) {
      // 这里可以加载数据
      console.log('RestaurantOil page visible, loading data...');
    }
  }, [visible, isTransitioning]);

  if (!visible && !isTransitioning) return null;

  // 根据transitionDirection确定合适的样式
  // 进入动画: 从两侧向中间运动 (in)
  // 退出动画: 从两侧向外运动 (out)
  const getTransform = () => {
    if (transitionDirection === 'in') {
      // 进入动画的初始状态或退出动画的最终状态
      if (isTransitioning && !visible) {
        return { left: 'translateX(-100%)', right: 'translateX(100%)' };
      } else if (isTransitioning && visible) {
        return { left: 'translateX(-100%)', right: 'translateX(100%)' };
      }
    } else if (transitionDirection === 'out') {
      // 退出动画的初始状态或进入动画的最终状态
      if (isTransitioning) {
        return { left: 'translateX(-100%)', right: 'translateX(100%)' };
      }
    }
    
    // 正常显示状态
    return { left: 'translateX(0)', right: 'translateX(0)' };
  };

  const transforms = getTransform();

  return (
    <div className={styles.container}>
      {/* 左侧内容区域 - 通过CSS设置pointer-events为auto，仅在有内容的区域启用事件 */}
      <div className={styles.leftSidebar} style={{ transform: transforms.left }}>
        <LeftContent />
      </div>
      
      {/* 中间区域 - 保持pointer-events: none让地图可交互 */}
      <div className={styles.centerContainer}>
        {/* 中部内容将在后续实现 */}
      </div>
      
      {/* 右侧内容 - 有实际内容的区域使用pointer-events: auto */}
      <div className={styles.rightContent} style={{ transform: transforms.right }}>
        <RightContent />
      </div>
    </div>
  );
};

export default RestaurantOil; 