import React, { useEffect, useState } from 'react';
import Header from './components/Header';
import HeaderOld from '@/layouts/Header';
import LeftSidebar from './components/LeftSidebar';
import MapContainer from './components/MapContainer';
import VideoCarousel from './components/VideoCarousel';
import RightContent from './components/RightContent';
import { DashboardProvider, useDashboard } from './components/context';
import RestaurantOil from './components/SubPages/RestaurantOil';
import classNames from 'classnames';
import styles from './index.less';

// 子页面内容组件
const PageContent: React.FC = () => {
  const { activePage, isTransitioning, transitionDirection } = useDashboard();
  const [prevPage, setPrevPage] = useState<string>('home');
  const [visiblePages, setVisiblePages] = useState<Set<string>>(new Set(['home']));

  // 当activePage改变时，更新可见页面列表
  useEffect(() => {
    // 如果是切换到新页面，先将新页面添加到可见列表
    if (activePage !== prevPage) {
      setVisiblePages(prev => {
        const newSet = new Set(prev);
        newSet.add(activePage);
        return newSet;
      });
      
      // 短暂延迟后移除之前的页面（等待过渡动画完成）
      setTimeout(() => {
        if (activePage !== 'home' && prevPage !== 'home') {
          setVisiblePages(prev => {
            const newSet = new Set(prev);
            newSet.delete(prevPage);
            return newSet;
          });
        }
        setPrevPage(activePage);
      }, 1000);
    }
  }, [activePage, prevPage]);

  // 主页内容
  const renderHomeContent = () => {
    const isHomePage = activePage === 'home';
    const isHomeTransitioning = isTransitioning && (activePage === 'home' || prevPage === 'home');
    
    // 确定左侧边栏样式
    const leftSidebarStyle = {
      transform: !isHomePage || (isHomeTransitioning && transitionDirection === 'in')
        ? 'translateX(-110%)'
        : isHomeTransitioning && transitionDirection === 'out'
          ? 'translateX(-110%)'
          : 'translateX(0)'
    };
    
    // 确定右侧内容样式
    const rightContentStyle = {
      transform: !isHomePage || (isHomeTransitioning && transitionDirection === 'in')
        ? 'translateX(110%)'
        : isHomeTransitioning && transitionDirection === 'out'
          ? 'translateX(110%)'
          : 'translateX(0)'
    };
    
    return (
      <>
        <div 
          className={styles.leftSidebar} 
          style={leftSidebarStyle}
        >
          <LeftSidebar />
        </div>
        <div className={styles.centerContainer}>
          <div className={classNames(styles.mapContainer, {
            [styles.mapContainer_expand]: activePage !== 'home'
          })}>
            <MapContainer />
          </div>
          <div className={classNames(styles.videoCarousel, {
            [styles.videoCarousel_exit]: activePage !== 'home' && transitionDirection === 'in',
            [styles.videoCarousel_enter]: activePage === 'home' && transitionDirection === 'out'
          })}>
            <VideoCarousel />
          </div>
        </div>
        <div 
          className={styles.rightContent}
          style={rightContentStyle}
        >
          <RightContent />
        </div>
      </>
    );
  };

  return (
    <>
      {/* 首页 */}
      {visiblePages.has('home') && renderHomeContent()}
      
      {/* 餐饮油烟子页面 */}
      {visiblePages.has('restaurantOil') && (
        <div 
          className={classNames(styles.subPageContainer, {
            [styles.subPage_enter]: activePage === 'restaurantOil' && isTransitioning && transitionDirection === 'in',
            [styles.subPage_active]: activePage === 'restaurantOil' && !isTransitioning,
            [styles.subPage_exit]: activePage !== 'restaurantOil' && isTransitioning && transitionDirection === 'out',
            [styles.hidden]: activePage !== 'restaurantOil' && !isTransitioning && !visiblePages.has('restaurantOil')
          })}
        >
          <RestaurantOil visible={activePage === 'restaurantOil'} />
        </div>
      )}
      
      {/* 可以添加更多子页面 */}
    </>
  );
};

const Home_v_2504: React.FC = () => {
  return (
    <DashboardProvider>
      <div className={styles.container}>
        <Header />
        {/* <HeaderOld /> */}
        <div className={styles.content}>
          <PageContent />
        </div>
      </div>
    </DashboardProvider>
  );
};

export default Home_v_2504; 